@@ -3,7 +3,8 @@
     options("gdiff.controlDir"="Control",
             "gdiff.testDir"="Test",
             "gdiff.compareDir"="Compare",
-            "gdiff.device"=pngDevice())
+            "gdiff.device"=pngDevice(),
+            "gdiff.pdftoppm"=Sys.which("pdftoppm"))
 }
 
 gdiffSessionFile <- ".gdiffSession"
